;+
; NAME:
;  oclc_ey92_atmparam
; PURPOSE: (one line)
;  convert "data parameters" to "atmospheric parameters"
; DESCRIPTION:
;  convert "data parameters" to "atmospheric parameters"
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  oclc_ey92_atmparam, v, dist, f, r0, 
;  timeim, timeem, timehiso, a, b,timeh1, timeh2, timehtau2, timemin, 
;  timemid, rhomin, nu0, lam0, r1, r2, kappa1 
; INPUTS:
;  v - sky-plane velocity, cm/s
;  dist - Observer-target distance, cm
;  f - flux level for timeim, timeem (unitless)
;  r0 - reference radius (cm)
;  order - expansion order for power series
;  timeim - time of immersion (s)
;  timeem - time of emersion (s)
;  timehiso - equivalent isothermal scale height in units of s.  
;   timehiso ~= 1/(8 dphi/dt) at haldlight)
;  a - exponent for molecular weight
;  b - exponent for temperature
;  timeh1 - time between tim and haze onset (s)
;  timeh2 - time between tim and optical-depth = 1
;  timehtau2 - scale height of haze at r2 in units of s
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  timemid - midtiime (s)
;  rhomin - minimum rho (cm)
;  nu0 - reference refractivity (unitless)
;  lam0 - reference energy ratio (unitless)
;  r1 - radius of haze onset (cm)
;  kappa1 - linear absorption at r1
;  Htau1 - scale height of absorption at r1
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.18
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-

pro oclc_ey92_atmparam, v, dist, f, r0, order, $
     timeim, timeem, timehiso, a, b,timeh1, timeh2, timehtau2, timemin, $
     timemid, rhomin, nu0, lam0, r1, kappa1, htau1, $
     rhof = rhof, r2 = r2
    
    ; mid time is the averaage of the immersion, emersion times
    timemid = (timeim + timeem)/2. ; eq 6.1

    ; rhomin in units of cm, not s
    rhomin = timemin * v        ; eq 5.8

    ; shadow radius of immersion and emersion

    rhof = sqrt( (v * (timeem - timemid) )^2 + rhomin^2) ; eq 5.1

    ; perpendicular velocity
    vperp = v * (v * (timeem-timemid) ) / rhof ; eq. 5.9

    ; scale height in units of cm, not s
    hiso = timehiso * vperp     ; eq 5.14

    ; iterate to find rf and lamf s.t. phi(rf) = f
    rf = rhof + hiso            ; eq 6.3
    lamf = rf/hiso - (3*a + 5*b)/2 ; eq 5.13
    repeat begin
        rflast = rf
        delta = 1/lamf
        aser = oclc_ey92_aseries(a,b,order,delta)
        bser = oclc_ey92_bseries(a,b,order,delta)
        dab = delta * aser/bser
        rf = rhof - $
          (rf/2) * (dab - 1 + $
                    sqrt(1 + (2 - 4/f) * dab + dab^2 ) $
                   )            ; eq. 6.5, 4.27
        lamf = rf/hiso - (3*a + 5*b)/2 ; eq 5.13
    endrep until abs(rf - rflast) lt 1.

    ; refractivity at rf (immersion, emersion radius)
    thetaf = (rhof - rf)/dist   ; eq 6.5
    aser = oclc_ey92_aseries(a,b,order,1/lamf)
    nuf = -thetaf / (aser * sqrt(2. * !pi * lamf))

    ; refractivity and energy ratio at reference radius
    nu0 = oclc_ey92_nu(rf,nuf,lamf,a,b, r0)
    lam0 = oclc_ey92_lam(rf,lamf, a, b, r0) 

    ; haze onset
    time1 = timeim + timeh1
    rho1 = oclc_ey92_rho_of_time(rhomin, timemid, v, time1)
    r1 = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b, dist, order, rho1)

    ; radius of tau_obs = 1, scale height of haze
    time2 = timeim + timeh2
    rho2 = oclc_ey92_rho_of_time(rhomin, timemid, v, time2)
    r2 = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b, dist, order, rho2)
    htau2 = timehtau2 * vperp
    htau1 = (r1/r2)^2 * htau2

    ; linear absorbtion at r1
    kappa1 = 1/oclc_ey92_tauobs(r1, 1., htau1, order, r2)
    
end
