;+
; NAME:
;  oclc_ey92_dtheta
; PURPOSE: (one line)
;  return dtheta (bending angle) as a function of radius
; DESCRIPTION:
;  return dtheta as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  dtheta = oclc_ey92_dtheta(r0,nu0,lam0,a,b,order, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  order - order for series expantion
;  r - radius at which to evaluat dtheta (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  dtheta at r
;  Derivative of the bending angle with respect to planet radius,
;  positive for an isothermal atmosphere.
;  radian/cm
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 4.11
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_dtheta, r0, nu0, lam0, a, b, order, r

    if n_params() eq 6 then order = 4

    lam = oclc_ey92_lam(r0,lam0,a,b,r)
    theta = oclc_ey92_theta(r0, nu0, lam0, a, b,order, r)
    aser = oclc_ey92_aseries(a,b,order,1.d/lam)
    bser = oclc_ey92_bseries(a,b,order,1.d/lam)
    dtheta = - (theta * lam/r) * bser/aser

    return, dtheta

end
