;+
; NAME:
;  oclc_ey92_lam
; PURPOSE: (one line)
;  return lambda (r/H) as a function of radius
; DESCRIPTION:
;  return lambda (r/H) as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  lam = oclc_ey92_lam(r0,lam0, a, b, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  r - radius at which to evaluat lam (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  lambda = r/H = (gravitational potential energy/kinetic energy)
;  Ratio of radius (r) to scale height (H).  Since H = kT r^2/(mu m_adu M G),
;  this is the same as the ratio of kinetic energy (kT) to potential
;  energy (mu m_adu M G/r).
;  unitless
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.9
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_lam, r0, lam0, a, b, r

    lam = lam0 * ( r/double(r0) ) ^(-(1.d + a + b))

    iinf = where(finite(lam) ne 1, ninf)
    if ninf ne 0 then stop

    return, lam

end
