;+
; NAME:
;  oclc_ey92_phi_of_r
; PURPOSE: (one line)
;  return phi (normalized stellar flux) as a function of planet radius, r
; DESCRIPTION:
;  return phi as a function of planet radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  phi = oclc_ey92_phi_of_r(r0, nu0, lam0, a, b, r1, kappa1, htau1,
;  dist, rsurf, order, r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar,
;         unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  r1 - top of haze layer
;  kappa1 - linear absorption coefficient at r1
;  htau1 - scale height of absorbtion coefficient
;  rsurf - surface radius
;  order - order for series expansion
;  r - radius at which to evaluat phi (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  stellar flux, phi, at planet radius, r
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 2.1, 2.2, 2.3
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_phi_of_r, r0, nu0, lam0, a, b, r1, kappa1, htau1, dist, rsurf, order, r

    n = n_elements(r)
    phi =  dblarr(n)
    ok = where(r ge rsurf, nok)
    if nok gt 0 then begin
        rok = r[ok]
        theta = oclc_ey92_theta(r0,nu0,lam0,a,b,order, rok)
        dtheta = oclc_ey92_dtheta(r0,nu0,lam0,a,b, order, rok)
        tau = oclc_ey92_tauobs(r1, kappa1, htau1,order, rok)

        phi[ok] = (1./abs(1+dist*dtheta)) * $ ; clear, cylindrical
          (1./abs(1.+dist*theta/rok)) * $ ; clear, lat'l focus
          exp(- (tau<100))      ; extinction

    endif

    if n eq 1 and not isarray(r) then phi = phi[0]
    
    return, phi

end
