;+
; NAME:
;  oclc_ey92_phi_of_rho
; PURPOSE: (one line)
;  return phi (normalized stellar flux) as a function of shadow radius
; DESCRIPTION:
;  return phi as a function of shadow radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  phi = oclc_ey92_phi_of_rho(r0,nu0,lam0,a,b,r1,kappa1,htau1,dist,rsurf,farside, haze, order, rho)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar,
;         unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  r1 - top of haze layer
;  kappa1 - linear absorption coefficient at r1
;  htau1 - scale height of absorbtion coefficient
;  rsurf - surface radius
;  farside - if 1, add farside contribution
;  haze - if 1, include haze extinction
;  order - order for series expansion
;  rho - shadow radius at which to evaluat phi (scalar or array, cm)
;  
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  r_near - the near-side planet radius (cm) 
; OUTPUTS:
;  phi (normalized stellar flux) at shadow radius, rho.
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 2.1, 2.2, 2.3
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_phi_of_rho, r0, nu0, lam0, a, b, $
                               r1, kappa1, htau1, dist, rsurf, $
                               farside, haze, order, $
                               rho, r_near=r_near
;print, 'oclc_ey92_phi_of_rho: haze = ', haze
    rhosurf = oclc_ey92_rho_of_r(r0,nu0,lam0,a,b,dist,order,rsurf)

    n = n_elements(rho)
    phi =  dblarr(n)
    r_near = dblarr(n)
    if rhosurf gt 0 then begin
        ok = where(rho ge abs(rhosurf), nok)
        if nok gt 0 then begin
            rok = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b,dist,order, rho[ok])
            r_near[ok] = rok
            theta = oclc_ey92_theta(r0,nu0,lam0,a,b, order,rok)
            dtheta = oclc_ey92_dtheta(r0,nu0,lam0,a,b, order,rok)
            tau = oclc_ey92_tauobs(r1, kappa1, htau1, order,rok)
            
            phi[ok] = (1./abs(1+dist*dtheta)) * $ ; clear, cylindrical
              (1./abs(1.+dist*theta/rok)) ; clear, lat'l focus
            if haze ne 0 then $
              phi[ok] = phi[ok] * exp(- (tau<100))  ; extinction
            
        endif
    endif else begin
        rok = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b,dist,order,rho)
        r_near = rok
        theta = oclc_ey92_theta(r0,nu0,lam0,a,b, order,rok)
        dtheta = oclc_ey92_dtheta(r0,nu0,lam0,a,b, order,rok)
        tau = oclc_ey92_tauobs(r1, kappa1, htau1, order,rok)
        phi = (1./abs(1+dist*dtheta)) * $ ; clear, cylindrical
          (1./abs(1.+dist*theta/rok))  ; clear, lat'l focus
        if haze then $
          phi = phi * exp(- (tau<100)) ; extinction

        ok = where( (rho) le abs(rhosurf), nok)
        if nok gt 0 then begin
            rok = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b,dist,order,rho[ok])
            theta = oclc_ey92_theta(r0,nu0,lam0,a,b, order,rok)
            dtheta = oclc_ey92_dtheta(r0,nu0,lam0,a,b, order,rok)
            tau = oclc_ey92_tauobs(r1, kappa1, htau1, order, rok)
            
            if farside ne 0 then begin
                phi[ok] = phi[ok] + $
                  (1./abs(1+dist*dtheta)) * $ ; clear, cylindrical
                  (1./abs(1.+dist*theta/rok))  ; clear, lat'l focus
                if haze ne 0 then $
                  phi[ok] = phi[ok] * exp(- (tau<100)) ; extinction
            endif
        endif
    endelse

    if n eq 1 and not isarray(rho) then phi = phi[0]
    
    return, phi

end
