;+
; NAME:
;  oclc_r_of_rho_ey92
; PURPOSE: (one line)
;  return r (planet radius) as a function of rho (shadow radius)
; DESCRIPTION:
;  return r as a function of rho
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  r = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b, dist, order, rho)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  dist - planet-observer distance (scalar, cm)
;  order - order for expansion of series
;  rho - shadow radius at which to evaluate r (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  r such that oclc_ey92_rho_of_r(r0,nu0,lam0,a,b,dist,r) = rho
;  r is radius (distance from planet center) in cm.
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 2.2
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_r_of_rho, r0, nu0, lam0, a, b, dist, order, rho

    n = n_elements(rho)
    if n gt 1 then begin
        dista = dblarr(n) + dist
        r = dblarr(n)
        for i = 0, n-1 do begin
            r[i] = oclc_ey92_r_of_rho(r0,nu0,lam0,a,b,dista[i],order,rho[i])
        end
        return, r
    end

    n = n_elements(rho)
    r = dblarr(n)
    h0 = r0 / lam0              ; reference scale height
    theta0 = oclc_ey92_theta(r0,nu0,lam0,a,b,order,r0)
    thetah = -h0/dist           ; approximate half-light theta
    if thetah ge 0 or theta0 ge 0 gt 1 then begin
        print, 'oclc_ey92_r_of_rho: error, positive theta'
        stop
    end
;print, 'oclc_ey92_r_of_rho: theta0', theta0
    lamh = lam0 + alog(thetah/theta0) ; approximate half-light lambda
    rh = r0 * lamh/lam0
    hh = rh/lamh
    rhoh = rh-hh
    
    for i=0,n-1 do begin
;        r[i] = rho[i]
;        dr = rho[i] - oclc_ey92_rho_of_r(r0,nu0,lam0,a,b,dist,order,r[i])

        y=(rho[i]-rhoh)/hh
        x=double(y-1.d)
        if y le -2.1528622055 then x = -alog(1-y)
        if y gt -2.1528622055 and y le 2 then x = y/2
        r[i] = hh * x + rh
        repeat begin
            dr = (rho[i]-oclc_ey92_rho_of_r(r0,nu0,lam0,a,b,dist,order,r[i])) / $
              (1. + dist * oclc_ey92_dtheta(r0,nu0,lam0, a, b,order, r[i]))
            r[i] = r[i] + dr
            h = r[i] / oclc_ey92_lam(r0,lam0,a,b,r[i])
        endrep until ( abs(dr) lt h * 1e-4) 
    end
    if n eq 1 and not isarray(rho) then r = r[0]
    return, r

end
