;+
; NAME:
;  oclc_ey92_tauobs
; PURPOSE: (one line)
;  return tauobs (line-of-sight optical depth) as a function of radius
; DESCRIPTION:
;  return tauobs as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  tauobs = oclc_ey92_tauobs(r1, kappa1, htau1, order, r)
; INPUTS:
;  r1 - top of haze layer
;  kappa1 - linear absorption coefficient at r1
;  htau1 - scale height of absorbtion coefficient
;  order - order for series
;  r - radius at which to evaluat tauobs (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  tauobs (line-of-sight optical depth, unitless) at r (planet radius, cm)
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 4.20
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_tauobs, r1, kappa1, htau1, order, r

    n = n_elements(r)
    tauobs = dblarr(n)
    ok = where(r lt r1, nok)  ; ok = list of "OK" = below haze top
    if nok gt 0 then begin
        rok = r[ok]
        kappa = kappa1 * exp( -(rok-r1)/(htau1 * (rok/r1) ) )
        tauobs[ok] = kappa * (rok/r1) * sqrt(2.d*!pi*htau1*rok) * $
          erf((r1/rok)*sqrt((r1^2. - rok^2)/(2. * htau1 * rok))) * $
          oclc_ey92_cseries(order,htau1 * rok/r1^2)
    end

    if n eq 1 and not isarray(rho) then tauobs = tauobs[0]
    
    return, tauobs

end
