;+
; NAME:
;  oclc_ey92_theta
; PURPOSE: (one line)
;  return theta (bending angle) as a function of radius
; DESCRIPTION:
;  return theta as a function of radius
; CATEGORY:
;  Occultation lightcurve (oclc)
; CALLING SEQUENCE:
;  theta = oclc_ey92_theta(r0,nu0,lam0,a,b,order,r)
; INPUTS:
;  r0 - reference radius (scalar, cm)
;  nu0 - refractivity at r0 (scalar, unitless)
;  lam0 - reference energy ratio (radius/scale height) (scalar, unitless)
;  a - exponent for non-constant mean moleculr weight
;      mu(r) = mu0 * (r/r0)^-a
;  b - exponent for non-constant temperature
;      T(r) = T * (r/r0)^b
;  order - order for series expansion
;  r - radius at which to evaluat theta (scalar or array, cm)
; OPTIONAL INPUT PARAMETERS:
;  none
; KEYWORD INPUT PARAMETERS:
;  none
; KEYWORD OUTPUT PARAMETERS:
;  none
; OUTPUTS:
;  theta at r
;  bending angle, negative for an isothermal atmosphere.
;  radians.
; COMMON BLOCKS:
;  None
; SIDE EFFECTS:
; RESTRICTIONS:
;  None
; PROCEDURE:
;  Elliot and Young 1992, AJ 103, pp 991; eg 3.20
; MODIFICATION HISTORY:
;  Written 2006 Jun 28, Leslie Young
;-


function oclc_ey92_theta, r0, nu0, lam0, a, b, order, r

    lam = oclc_ey92_lam(r0,lam0,a,b,r)
    nu = oclc_ey92_nu(r0,nu0,lam0,a,b, r)
    theta = - (sqrt(2.d * !dpi * lam) * nu * oclc_ey92_aseries(a,b,order,1.d/lam))

    return, theta

end
